@@ -1,6 +1,6 @@
-from FilesOp.File import File
+from .File import *
 
 __author__ = """KingKaitoKid"""
 __email__ = 'djstrix@me.com'
-__version__ = '1.0.8'
+__version__ = '1.0.9'
 name = "FilesOp"
\ No newline at end of file
